function [rho, mx, my, Obj] = proxNewton(rho0,rho1,x_max,N,T,params)
[rho, mx, my]=initial(rho0, rho1, x_max, T);
[A, b]=div(rho0, rho1, x_max, N ,T);
u=transfer(rho,mx, my); 
dx = x_max/(N-1);
maxIter = params.maxIter; 
tol = params.tol; 
h = params.stepsz; 

beta = params.beta;

Obj=[];
options = optimoptions('quadprog',...
    'Algorithm','interior-point-convex','Display','off');

fprintf('%s %18s %20s %20s\n','Iter', 'Obj', 'relerr', 'step sz')
for k = 1:maxIter
    H = hessian(u,x_max, N, T, beta);    
    gradu = grad(u,x_max, N, T, beta);
    
    x = quadprog(H,gradu-H*u,[],[],A,b,[],[],[],options);
    du = x - u;
    u = u + h*du;
    [rho, mx, my]=transfer1(u, N, T);
    obj = energy(u, N, T, dx, beta);
    Obj= [Obj; obj];
    
    if k == 1
        relerr = inf;
    else
        relerr = abs(obj-Obj(k-1))/abs(Obj(k-1));
    end
    fprintf('%d %20.2e %20.2e %20.2f\n',k,obj,relerr,h);
    if relerr < tol;
        disp(['Tolerance met after ' num2str(k) ' iterations'])
        break;
    end
end
end